@@ -25,7 +25,7 @@ logger_debug_enabled = False
 def getLogger(name=None):  # noqa
     logger = logging.getLogger(name)
     ch = logging.StreamHandler()
-    formatter = logging.Formatter('%(name)s [%(threadName)s] [%(levelname)s] %(message)s')
+    formatter = logging.Formatter('%(asctime)s %(name)s [pid:%(process)d] [%(threadName)s] [%(levelname)s] %(message)s')
     ch.setFormatter(formatter)
     logger.addHandler(ch)
     logger.propagate = False
@@ -39,5 +39,5 @@ logger = getLogger('skywalking')
 def init():
     global logger_debug_enabled
     logging.addLevelName(logging.CRITICAL + 10, 'OFF')
-    logger.setLevel(logging.getLevelName(config.logging_level))
+    logger.setLevel(logging.getLevelName(config.agent_logging_level))
     logger_debug_enabled = logger.isEnabledFor(logging.DEBUG)
