@@ -23,4 +23,4 @@ class DataSource:
         for name in dir(self):
             if name.endswith('generator'):
                 generator = getattr(self, name)()
-                Gauge.Builder('instance_pvm_' + name[:-10], generator).build()
+                Gauge.Builder(f'instance_pvm_{name[:-10]}', generator).build()
