@@ -18,7 +18,22 @@
 if __name__ == '__main__':
     import pulsar
 
-    client = pulsar.Client(service_url='pulsar://pulsar-server:6650')
+    client = pulsar.Client(
+        service_url='pulsar://pulsar-server:6650',
+        authentication=None,
+        operation_timeout_seconds=30,
+        io_threads=1,
+        message_listener_threads=1,
+        concurrent_lookup_requests=50000,
+        log_conf_file_path=None,
+        use_tls=False,
+        tls_trust_certs_file_path=None,
+        tls_allow_insecure_connection=False,
+        tls_validate_hostname=False,
+        logger=None,
+        connection_timeout_ms=10000,
+        listener_name=None
+    )
     consumer = client.subscribe('sw-topic', 'sw-subscription')
 
     while True:
