@@ -68,6 +68,12 @@ class _NewID(ID):
     pass
 
 
+class _NewNoopID(ID):
+
+    def __init__(self):
+        self.value = ''
+
+
 @tostring
 class Segment(object):
     def __init__(self):
@@ -75,6 +81,7 @@ class Segment(object):
         self.spans = []  # type: List[Span]
         self.timestamp = int(time.time() * 1000)  # type: int
         self.related_traces = [_NewID()]  # type: List[ID]
+        self.is_size_limited = False  # type: bool
 
     def archive(self, span: 'Span'):
         self.spans.append(span)
@@ -83,3 +90,11 @@ class Segment(object):
         if isinstance(self.related_traces[0], _NewID):
             del self.related_traces[-1]
         self.related_traces.append(trace_id)
+
+
+class NoopSegment(Segment):
+    def __init__(self):
+        self.segment_id = _NewNoopID()
+        self.spans = []
+        self.timestamp = 0
+        self.related_traces = [_NewNoopID()]
